



if not exist %LIBRARY_BIN%\\libomp.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\libomp.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\omp.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
%LIBRARY_BIN%\clang -v -fopenmp -I%LIBRARY_INC% -L%LIBRARY_LIB% omp_hello.c -o omp_hello.exe
IF %ERRORLEVEL% NEQ 0 exit /B 1
%cd%\omp_hello.exe
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
